@@ -52,6 +52,7 @@ async def pick_new_edge(document_controller, model_data_item, edge) -> None:
         - the edge reference is used to recognize the eels line plot as associated with the referenced edge
     """
     document_model = document_controller.document_model
+    project = document_model._project
     model_display_item = document_model.get_display_item_for_data_item(model_data_item)
     pick_region = Graphics.RectangleGraphic()
     pick_region.size = min(1 / 16, 16 / model_data_item.dimensional_shape[0]), min(1 / 16, 16 / model_data_item.dimensional_shape[1])
@@ -85,12 +86,12 @@ async def pick_new_edge(document_controller, model_data_item, edge) -> None:
     document_model.append_connection(Connection.PropertyConnection(edge.data_structure, "signal_interval", signal_region, "interval", parent=eels_data_item))
 
     computation = document_model.create_computation()
-    computation.create_object("eels_xdata", document_model.get_object_specifier(model_data_item, "xdata"))
-    computation.create_object("region", document_model.get_object_specifier(pick_region))
-    computation.create_input("fit_interval", document_model.get_object_specifier(edge.data_structure), "fit_interval")
-    computation.create_input("signal_interval", document_model.get_object_specifier(edge.data_structure), "signal_interval")
+    computation.create_input_item("eels_xdata", Symbolic.make_item(model_data_item, type="xdata"))
+    computation.create_input_item("region", Symbolic.make_item(pick_region))
+    computation.create_input_item("fit_interval", Symbolic.make_item(edge.data_structure), property_name="fit_interval")
+    computation.create_input_item("signal_interval", Symbolic.make_item(edge.data_structure), property_name="signal_interval")
     computation.processing_id = "eels.background_subtraction11"
-    computation.create_result("data", document_model.get_object_specifier(eels_data_item))
+    computation.create_output_item("data", Symbolic.make_item(eels_data_item))
     document_model.append_computation(computation)
 
     # the eels item will need the initial computation results to display properly (view to intervals)
@@ -125,6 +126,7 @@ async def change_edge(document_controller: DocumentController.DocumentController
         - the edge reference will reference the new edge
     """
     document_model = document_controller.document_model
+    project = document_model._project
 
     computation = None  # type: Symbolic.Computation
     for computation_ in document_model.computations:
@@ -159,9 +161,8 @@ async def change_edge(document_controller: DocumentController.DocumentController
             new_connection = Connection.PropertyConnection(edge.data_structure, source_property, target, target_property, parent=eels_data_item)
             document_model.append_connection(new_connection)
 
-    for computation_variable in computation.variables:
-        if computation_variable.name in ("fit_interval", "signal_interval"):
-            computation_variable.specifier = document_model.get_object_specifier(edge.data_structure)
+    computation.set_input_item("fit_interval", Symbolic.make_item(edge.data_structure))
+    computation.set_input_item("signal_interval", Symbolic.make_item(edge.data_structure))
 
     eels_data_item.title = "{} EELS Data of {}".format(pick_region.label, model_data_item.title)
 
@@ -187,8 +188,17 @@ class EELSMapping:
     def __init__(self, computation, **kwargs):
         self.computation = computation
 
-    def execute(self, spectrum_image_xdata, fit_interval, signal_interval):
-        self.__mapped_xdata = eels_analysis.map_background_subtracted_signal(spectrum_image_xdata, None, [fit_interval], signal_interval)
+    def execute(self, **kwargs):
+        spectrum_image_xdata = kwargs["spectrum_image_xdata"]
+        fit_interval = kwargs["fit_interval"]
+        signal_interval = kwargs["signal_interval"]
+        atomic_number = kwargs.get("atomic_number")
+        shell_number = kwargs.get("shell_number")
+        subshell_index = kwargs.get("subshell_index")
+        electron_shell = None
+        if atomic_number is not None and shell_number is not None and subshell_index is not None:
+            electron_shell = PeriodicTable.ElectronShell(atomic_number, shell_number, subshell_index)
+        self.__mapped_xdata = eels_analysis.map_background_subtracted_signal(spectrum_image_xdata, electron_shell, [fit_interval], signal_interval)
 
     def commit(self):
         self.computation.set_referenced_xdata("map", self.__mapped_xdata)
@@ -196,6 +206,7 @@ class EELSMapping:
 
 async def map_new_edge(document_controller, model_data_item, edge) -> None:
     document_model = document_controller.document_model
+    project = document_model._project
 
     map_data_item = DataItem.new_data_item()
     map_data_item.title = "{} of {}".format(_("Map"), str(edge.electron_shell))
@@ -205,11 +216,14 @@ async def map_new_edge(document_controller, model_data_item, edge) -> None:
 
     computation = document_model.create_computation()
     computation.source = map_data_item
-    computation.create_object("spectrum_image_xdata", document_model.get_object_specifier(model_data_item, "xdata"))
-    computation.create_input("fit_interval", document_model.get_object_specifier(edge.data_structure), "fit_interval")
-    computation.create_input("signal_interval", document_model.get_object_specifier(edge.data_structure), "signal_interval")
+    computation.create_input_item("spectrum_image_xdata", Symbolic.make_item(model_data_item, type="xdata"))
+    computation.create_input_item("fit_interval", Symbolic.make_item(edge.data_structure), property_name="fit_interval")
+    computation.create_input_item("signal_interval", Symbolic.make_item(edge.data_structure), property_name="signal_interval")
+    computation.create_variable(name="atomic_number", value_type="integral", value=edge.electron_shell.atomic_number)
+    computation.create_variable(name="shell_number", value_type="integral", value=edge.electron_shell.shell_number)
+    computation.create_variable(name="subshell_index", value_type="integral", value=edge.electron_shell.subshell_index)
     computation.processing_id = "eels.mapping"
-    computation.create_result("map", document_model.get_object_specifier(map_data_item))
+    computation.create_output_item("map", Symbolic.make_item(map_data_item))
     document_model.append_computation(computation)
 
     await document_model.compute_immediate(document_controller.event_loop, computation)
@@ -409,7 +423,7 @@ class ElementalMappingController:
         pick_region.size = min(1 / 16, 16 / model_data_item.dimensional_shape[0]), min(1 / 16, 16 / model_data_item.dimensional_shape[1])
         pick_region.label = _("Explore")
         model_display_item.add_graphic(pick_region)
-        pick_data_item = document_model.get_pick_region_new(model_display_item, pick_region=pick_region)
+        pick_data_item = document_model.get_pick_region_new(model_display_item, model_display_item.data_item, pick_region=pick_region)
         if pick_data_item:
             explore_interval = Graphics.IntervalGraphic()
             explore_interval.interval = 0.4, 0.6
@@ -423,6 +437,7 @@ class ElementalMappingController:
             self.__connect_explorer_interval(document_model, pick_data_item)
 
     def __add_edge(self, data_item, electron_shell, fit_interval, signal_interval) -> ElementalMappingEdge:
+        project = self.__document_model._project
         data_structure = self.__document_model.create_data_structure(structure_type="elemental_mapping_edge", source=data_item)
         self.__document_model.append_data_structure(data_structure)
         edge = ElementalMappingEdge(electron_shell=electron_shell, fit_interval=fit_interval, signal_interval=signal_interval)
@@ -529,9 +544,9 @@ class ElementalMappingController:
         model_data_item = self.__model_data_item
         if not model_data_item:
             return
+        project = document_model._project
         multiprofile_display_item = None
         line_profile_regions = list()
-        items = list()
 
         colors = ("rgba(0, 0, 255, 0.5)", "rgba(255, 0, 0, 0.5)", "rgba(0, 255, 0, 0.5)")
 
@@ -544,12 +559,11 @@ class ElementalMappingController:
                     multiprofile_display_item.display_type = "line_plot"
                     multiprofile_display_item.set_display_property("legend_position", "top-right")
                     document_model.append_display_item(multiprofile_display_item)
-                line_profile_data_item = document_model.get_line_profile_new(dependent_display_item)
+                line_profile_data_item = document_model.get_line_profile_new(dependent_display_item, dependent_display_item.data_item)
                 line_profile_display_item = document_model.get_display_item_for_data_item(line_profile_data_item)
                 line_profile_display_data_channel = line_profile_display_item.get_display_data_channel_for_data_item(line_profile_data_item)
                 line_profile_region = dependent_display_item.graphics[0]
                 line_profile_region.vector = (0.5, 0.2), (0.5, 0.8)
-                items.append(document_model.get_object_specifier(line_profile_display_data_channel, "display_xdata"))
                 line_profile_regions.append(line_profile_region)
                 multiprofile_display_item.append_display_data_channel_for_data_item(line_profile_data_item)
                 display_layers = multiprofile_display_item.display_layers
